@@ -43,12 +43,15 @@ class SearchApplicationClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Delete a search application. Remove a search application and its associated alias.
-        Indices attached to the search application are not removed.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/delete-search-application.html>`_
+          <p>Delete a search application.</p>
+          <p>Remove a search application and its associated alias. Indices attached to the search application are not removed.</p>
 
-        :param name: The name of the search application to delete
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-search-application-delete>`_
+
+        :param name: The name of the search application to delete.
         """
         if name in SKIP_IN_PATH:
             raise ValueError("Empty value passed for parameter 'name'")
@@ -85,10 +88,13 @@ class SearchApplicationClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Delete a behavioral analytics collection. The associated data stream is also
-        deleted.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/delete-analytics-collection.html>`_
+          <p>Delete a behavioral analytics collection.
+          The associated data stream is also deleted.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-search-application-delete-behavioral-analytics>`_
 
         :param name: The name of the analytics collection to be deleted
         """
@@ -127,9 +133,12 @@ class SearchApplicationClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get search application details.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/get-search-application.html>`_
+          <p>Get search application details.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-search-application-get>`_
 
         :param name: The name of the search application
         """
@@ -168,9 +177,12 @@ class SearchApplicationClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Get behavioral analytics collections.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/list-analytics-collection.html>`_
+          <p>Get behavioral analytics collections.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-search-application-get-behavioral-analytics>`_
 
         :param name: A list of analytics collections to limit the returned information
         """
@@ -216,9 +228,13 @@ class SearchApplicationClient(NamespacedClient):
         size: t.Optional[int] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns the existing search applications.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/list-search-applications.html>`_
+          <p>Get search applications.
+          Get information about search applications.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-search-application-get-behavioral-analytics>`_
 
         :param from_: Starting offset.
         :param q: Query in the Lucene query string syntax.
@@ -251,6 +267,74 @@ class SearchApplicationClient(NamespacedClient):
             path_parts=__path_parts,
         )
 
+    @_rewrite_parameters(
+        body_name="payload",
+    )
+    @_stability_warning(Stability.EXPERIMENTAL)
+    async def post_behavioral_analytics_event(
+        self,
+        *,
+        collection_name: str,
+        event_type: t.Union[str, t.Literal["page_view", "search", "search_click"]],
+        payload: t.Optional[t.Any] = None,
+        body: t.Optional[t.Any] = None,
+        debug: t.Optional[bool] = None,
+        error_trace: t.Optional[bool] = None,
+        filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
+        human: t.Optional[bool] = None,
+        pretty: t.Optional[bool] = None,
+    ) -> ObjectApiResponse[t.Any]:
+        """
+        .. raw:: html
+
+          <p>Create a behavioral analytics collection event.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-search-application-post-behavioral-analytics-event>`_
+
+        :param collection_name: The name of the behavioral analytics collection.
+        :param event_type: The analytics event type.
+        :param payload:
+        :param debug: Whether the response type has to include more details
+        """
+        if collection_name in SKIP_IN_PATH:
+            raise ValueError("Empty value passed for parameter 'collection_name'")
+        if event_type in SKIP_IN_PATH:
+            raise ValueError("Empty value passed for parameter 'event_type'")
+        if payload is None and body is None:
+            raise ValueError(
+                "Empty value passed for parameters 'payload' and 'body', one of them should be set."
+            )
+        elif payload is not None and body is not None:
+            raise ValueError("Cannot set both 'payload' and 'body'")
+        __path_parts: t.Dict[str, str] = {
+            "collection_name": _quote(collection_name),
+            "event_type": _quote(event_type),
+        }
+        __path = f'/_application/analytics/{__path_parts["collection_name"]}/event/{__path_parts["event_type"]}'
+        __query: t.Dict[str, t.Any] = {}
+        if debug is not None:
+            __query["debug"] = debug
+        if error_trace is not None:
+            __query["error_trace"] = error_trace
+        if filter_path is not None:
+            __query["filter_path"] = filter_path
+        if human is not None:
+            __query["human"] = human
+        if pretty is not None:
+            __query["pretty"] = pretty
+        __body = payload if payload is not None else body
+        __headers = {"accept": "application/json", "content-type": "application/json"}
+        return await self.perform_request(  # type: ignore[return-value]
+            "POST",
+            __path,
+            params=__query,
+            headers=__headers,
+            body=__body,
+            endpoint_id="search_application.post_behavioral_analytics_event",
+            path_parts=__path_parts,
+        )
+
     @_rewrite_parameters(
         body_name="search_application",
     )
@@ -268,9 +352,12 @@ class SearchApplicationClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Create or update a search application.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/put-search-application.html>`_
+          <p>Create or update a search application.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-search-application-put>`_
 
         :param name: The name of the search application to be created or updated.
         :param search_application:
@@ -322,9 +409,12 @@ class SearchApplicationClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Create a behavioral analytics collection.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/put-analytics-collection.html>`_
+          <p>Create a behavioral analytics collection.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-search-application-put-behavioral-analytics>`_
 
         :param name: The name of the analytics collection to be created or updated.
         """
@@ -351,6 +441,71 @@ class SearchApplicationClient(NamespacedClient):
             path_parts=__path_parts,
         )
 
+    @_rewrite_parameters(
+        body_fields=("params",),
+        ignore_deprecated_options={"params"},
+    )
+    @_stability_warning(Stability.EXPERIMENTAL)
+    async def render_query(
+        self,
+        *,
+        name: str,
+        error_trace: t.Optional[bool] = None,
+        filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
+        human: t.Optional[bool] = None,
+        params: t.Optional[t.Mapping[str, t.Any]] = None,
+        pretty: t.Optional[bool] = None,
+        body: t.Optional[t.Dict[str, t.Any]] = None,
+    ) -> ObjectApiResponse[t.Any]:
+        """
+        .. raw:: html
+
+          <p>Render a search application query.
+          Generate an Elasticsearch query using the specified query parameters and the search template associated with the search application or a default template if none is specified.
+          If a parameter used in the search template is not specified in <code>params</code>, the parameter's default value will be used.
+          The API returns the specific Elasticsearch query that would be generated and run by calling the search application search API.</p>
+          <p>You must have <code>read</code> privileges on the backing alias of the search application.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-search-application-render-query>`_
+
+        :param name: The name of the search application to render teh query for.
+        :param params:
+        """
+        if name in SKIP_IN_PATH:
+            raise ValueError("Empty value passed for parameter 'name'")
+        __path_parts: t.Dict[str, str] = {"name": _quote(name)}
+        __path = (
+            f'/_application/search_application/{__path_parts["name"]}/_render_query'
+        )
+        __query: t.Dict[str, t.Any] = {}
+        __body: t.Dict[str, t.Any] = body if body is not None else {}
+        if error_trace is not None:
+            __query["error_trace"] = error_trace
+        if filter_path is not None:
+            __query["filter_path"] = filter_path
+        if human is not None:
+            __query["human"] = human
+        if pretty is not None:
+            __query["pretty"] = pretty
+        if not __body:
+            if params is not None:
+                __body["params"] = params
+        if not __body:
+            __body = None  # type: ignore[assignment]
+        __headers = {"accept": "application/json"}
+        if __body is not None:
+            __headers["content-type"] = "application/json"
+        return await self.perform_request(  # type: ignore[return-value]
+            "POST",
+            __path,
+            params=__query,
+            headers=__headers,
+            body=__body,
+            endpoint_id="search_application.render_query",
+            path_parts=__path_parts,
+        )
+
     @_rewrite_parameters(
         body_fields=("params",),
         ignore_deprecated_options={"params"},
@@ -369,12 +524,14 @@ class SearchApplicationClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Run a search application search. Generate and run an Elasticsearch query that
-        uses the specified query parameteter and the search template associated with
-        the search application or default template. Unspecified template parameters are
-        assigned their default values if applicable.
+        .. raw:: html
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/search-application-search.html>`_
+          <p>Run a search application search.
+          Generate and run an Elasticsearch query that uses the specified query parameteter and the search template associated with the search application or default template.
+          Unspecified template parameters are assigned their default values if applicable.</p>
+
+
+        `<https://www.elastic.co/docs/api/doc/elasticsearch/operation/operation-search-application-search>`_
 
         :param name: The name of the search application to be searched.
         :param params: Query parameters specific to this request, which will override
